# %% imports
import pandas as pd
from matplotlib import pyplot as plt

# %% read data
df_dec = pd.read_csv(
    "enum_decorated_results.csv",
    names=[
        "py_ver",
        "trans_ver",
        "models",
        "time",
        "stddev",
    ],
    dtype={
        "py_ver": str,
        "trans_ver": str,
        "models": int,
        "time": float,
        "stddev": float,
    },
)

df_undec = pd.read_csv(
    "enum_undecorated_results.csv",
    names=[
        "py_ver",
        "trans_ver",
        "models",
        "time",
        "stddev",
    ],
    dtype={
        "py_ver": str,
        "trans_ver": str,
        "models": int,
        "time": float,
        "stddev": float,
    },
)

# %% plot init time vs states

p = df_dec[df_dec["trans_ver"] == "0.9.1"]
p1 = pd.DataFrame(
    {k: p[p["py_ver"] == k]["time"].values for k in sorted(p.py_ver.unique())},
    index=p[p["py_ver"] == "3.12"]["models"].values,
)
p1.plot.bar(
    title="Model state change transitions 0.9.1\n(adding n models, cycling through n states, removing n models)",
    xlabel="Number of states (n)",
    ylabel="Time (ms)",
)

# %% plot init time vs states

fig, ax = plt.subplots(ncols=2, sharey=True, figsize=(12, 6))
fig.suptitle("Initializing n models, adding n models to machine,\ncycling through 50 states and removing models.", y=1.05)
p = df_dec[df_dec["py_ver"] == "3.12"]
p1 = pd.DataFrame(
    {k: p[p["trans_ver"] == k]["time"].values for k in sorted(p.trans_ver.unique())},
    index=p[p["trans_ver"] == "0.9.1"]["models"].values,
)
p1.plot.bar(
    title="decorated",
    xlabel="Number of states",
    ylabel="Time (ms)",
    ax=ax[0],
)
p = df_undec[df_undec["py_ver"] == "3.12"]
p1 = pd.DataFrame(
    {k: p[p["trans_ver"] == k]["time"].values for k in sorted(p.trans_ver.unique())},
    index=p[p["trans_ver"] == "0.9.1"]["models"].values,
)
p1.plot.bar(
    title="undecorated",
    xlabel="Number of models",
    ylabel="Time (ms)",
    legend=False,
    ax=ax[1],
)
# %%
