# %% imports
import pandas as pd
from matplotlib import pyplot as plt
from matplotlib.patches import Patch


# %% read data
df = pd.read_csv(
    "init_models_results.csv",
    names=[
        "py_ver",
        "trans_ver",
        "states",
        "models",
        "with_auto",
        "time",
        "stddev",
    ],
    dtype={
        "py_ver": str,
        "trans_ver": str,
        "with_auto": bool,
        "states": int,
        "models": int,
        "time": float,
        "stddev": float,
    },
)

# %% plot init time vs states

p = df[(df.with_auto) & (df.models == 50) & (df.trans_ver == "0.9.1")]
p1 = pd.DataFrame(
    {k: p[p["py_ver"] == k]["time"].values for k in sorted(p.py_ver.unique())},
    index=p[p["py_ver"] == "3.12"]["states"].values,
)
p1.plot.bar(
    title="Machine Initialization transitions 0.9.1 (50 models and auto transitions)",
    xlabel="Number of states",
    ylabel="Time (ms)",
)

# %% plot init time vs states

p = df[(df.with_auto) & (df.models == 50) & (df.py_ver == "3.11")]
p1 = pd.DataFrame(
    {k: p[p["trans_ver"] == k]["time"].values for k in sorted(p.trans_ver.unique())},
    index=p[p["trans_ver"] == "0.9.1"]["states"].values,
)
p1.plot.bar(
    title="Machine Initialization Time Python 3.12 (50 models and auto transitions)",
    xlabel="Number of states",
    ylabel="Time (ms)",
)

# %% plot init time vs states
colors = {5: "g", 10: "y", 20: "b", 50: "r"}
fig, ax = plt.subplots()

for wt in reversed(colors.keys()):
    p = df[(df.with_auto) & (df.models == wt) & (df.py_ver == "3.12")]
    p1 = pd.DataFrame(
        {k: p[p["trans_ver"] == k]["time"].values for k in sorted(p.trans_ver.unique())},
        index=p[p["trans_ver"] == "0.9.1"]["states"].values,
    )
    p1.plot.bar(
        title="Machine Initialization Time Python 3.12 (states and transitions)",
        xlabel="Number of states",
        ylabel="Time (ms)",
        ax = ax,
        color=colors[wt],
        legend = False
    )
plt.legend(handles=[Patch(color=c, label=f"{n_models} models") for n_models, c in colors.items()])

# %%
