# %% imports
import pandas as pd
from matplotlib import pyplot as plt
from matplotlib.patches import Patch

# %% read data
df = pd.read_csv(
    "init_results.csv",
    names=[
        "py_ver",
        "trans_ver",
        "states",
        "with_auto",
        "with_trans",
        "time",
        "stddev",
    ],
    dtype={
        "py_ver": str,
        "trans_ver": str,
        "with_auto": bool,
        "with_trans": bool,
        "states": int,
        "time": float,
        "stddev": float,
    },
)

# %% plot init time vs states
p = df[(~df.with_auto) & (~df.with_trans) & (df.trans_ver == "0.9.1")]
p1 = pd.DataFrame(
    {k: p[p["py_ver"] == k]["time"].values for k in sorted(p.py_ver.unique())},
    index=p[p["py_ver"] == "3.12"]["states"].values,
)
p1.plot.bar(
    title="Machine Initialization transitions 0.9.1 (states only)",
    xlabel="Number of states",
    ylabel="Time (ms)",
)

# %% plot init time vs states
p = df[(~df.with_auto) & (~df.with_trans) & (df.py_ver == "3.12")]
p1 = pd.DataFrame(
    {k: p[p["trans_ver"] == k]["time"].values for k in sorted(p.trans_ver.unique())},
    index=p[p["trans_ver"] == "0.9.0"]["states"].values,
)
p1.plot.bar(
    title="Machine Initialization Time Python 3.12 (states only)",
    xlabel="Number of states",
    ylabel="Time (ms)",
)

# %% plot init time vs states
colors = {(False, False): "g", (False, True): "y", (True, False): "b", (True, True): "r"}
fig, ax = plt.subplots()

for wa in [True, False]:
    for wt in [True, False]:
        p = df[df["with_auto"] == wa]
        p = p[p["with_trans"] == wt]
        p = p[p["py_ver"] == "3.12"]
        p1 = pd.DataFrame(
            {k: p[p["trans_ver"] == k]["time"].values for k in sorted(p.trans_ver.unique())},
            index=p[p["trans_ver"] == "0.9.1"]["states"].values,
        )
        p1.plot.bar(
            title="Machine Initialization Time Python 3.12 (states and transitions)",
            xlabel="Number of states",
            ylabel="Time (ms)",
            ax = ax,
            color=colors[wa, wt],
            legend = False
        )
plt.legend(handles=[Patch(color=c, label=f"auto={settings[0]}, trans={settings[1]}") for settings, c in colors.items()])
# %%
