from transitions import Machine, __version__
from enum import Enum


class Model:
    
    def callback(self):
        pass


state_nr = [2, 10, 50, 100]
trials = 5
n_iter = 5

state_dict = {n: Enum("StateEnum", {f"State{i}": i for i in range(n)}) for n in state_nr}

machines_dict = {
    n: Machine(
        model=None,
        states=state_dict[n], initial=state_dict[n].State0,
        after_state_change="callback",
        auto_transitions=False,
        ordered_transitions=True
    )
    for n in state_nr
}


def test_enum(n):
    machine = machines_dict[n]
    stack = []
    for _ in range(n):
        model = Model()
        machine.add_model(model)
        stack.append(model)
        machine.dispatch("next_state")
        while model.state != state_dict[n].State0:
            machine.dispatch("next_state")
    while stack:
        machine.remove_model(stack.pop())


if __name__ == "__main__":
    import timeit
    import sys

    pyver = f"{sys.version_info.major}.{sys.version_info.minor}"
    print(f"{pyver} : {__version__}")
    with open("enum_results.csv", "a") as f:
        for n in state_nr:
            samples = [
                timeit.timeit(
                    f"test_enum({n})",
                    globals=globals(),
                    number=1,
                )
                * 1000 / n_iter
                for _ in range(trials)
            ]
            mean = sum(samples) / trials
            stddev = (sum((x - mean) ** 2 for x in samples) / trials) ** 0.5
            print(
                f'"{pyver}","{__version__}","{n}","{mean:.2f}","{stddev:.2f}"',
                file=f,
            )
