from transitions import Machine, __version__
from enum import Enum


class Model:
    def __init__(self, machine) -> None:
        self.machine = machine
        self.state = self.machine.initial
        self.machine.models.append(self)

    def trigger(self, trigger_name, *args, **kwargs):
        return self.machine.events[trigger_name]\
            .trigger(self, *args, **kwargs)

    def callback(self):
        pass


model_nr = [25, 50, 75, 100, 250, 500, 1000]
trials = 5
n_iter = 5

states = Enum("StateEnum", {f"State{i}": i for i in range(50)})

machine = Machine(
    model=None,
    states=states,
    initial=states.State0,
    after_state_change="callback",
    auto_transitions=False,
    ordered_transitions=True,
)


def test_enum(n):
    for _ in range(n_iter):
        for _ in range(n):
            model = Model(machine)
        for mod in machine.models:
            mod.trigger("next_state")
        while model.state != states.State0:
            for mod in machine.models:
                mod.trigger("next_state")
        while machine.models:
            _ = machine.models.pop()


if __name__ == "__main__":
    import timeit
    import sys

    pyver = f"{sys.version_info.major}.{sys.version_info.minor}"
    print(f"{pyver} : {__version__}")
    with open("enum_undecorated_results.csv", "a") as f:
        for n in model_nr:
            samples = [
                timeit.timeit(
                    f"test_enum({n})",
                    globals=globals(),
                    number=1,
                )
                * 1000
                / n_iter
                for _ in range(trials)
            ]
            mean = sum(samples) / trials
            stddev = (sum((x - mean) ** 2 for x in samples) / trials) ** 0.5
            print(
                f'"{pyver}","{__version__}","{n}","{mean:.2f}","{stddev:.2f}"',
                file=f,
            )
