from transitions import Machine, __version__

state_nr = [1, 5, 10, 20, 50, 75, 100]
trials = 5
n_runs = 2000 // trials

state_dict = {n: [f"State_{i}" for i in range(n)] for n in state_nr}
trans_dict = {n: [["go", a, b] for a, b in zip(state_dict[n][:-1], state_dict[n][1:])] for n in state_nr}


def test_init_machine(n, with_auto, with_trans):
    for _ in range(n_runs):
        _ = Machine(states=state_dict[n], transitions=trans_dict[n] if with_trans else None, initial=state_dict[n][0], auto_transitions=with_auto)

if __name__ == '__main__':
    import timeit
    import sys
    pyver = f"{sys.version_info.major}.{sys.version_info.minor}"
    print(f"{pyver} : {__version__}")
    with open('init_results.csv', 'a') as f:
        for n in state_nr:
            for with_auto in [True, False]:
                for with_trans in [True, False]:
                    samples = [timeit.timeit(f'test_init_machine({n}, {with_auto}, {with_trans})', globals=globals(), number=1) * 1000 / n_runs for _ in range(trials)]
                    mean = sum(samples) / trials
                    stddev = (sum((x - mean) ** 2 for x in samples) / trials) ** 0.5
                    print(f'"{pyver}","{__version__}","{n}","{with_auto}","{with_trans}","{mean:.2f}","{stddev:.2f}"', file=f)
