from transitions import Machine, __version__

state_nr = [1, 10, 50, 100]
trials = 5
n_iter = 10
state_dict = {n: [f"State_{i}" for i in range(n)] for n in state_nr}
trans_dict = {
    n: [["go", a, b] for a, b in zip(state_dict[n][:-1], state_dict[n][1:])]
    for n in state_nr
}


class Model:
    def callback(self):
        pass


machines_dict = {
    n: Machine(
        model=[Model() for _ in range(n * 10)],
        states=state_dict[n],
        transitions=trans_dict[n],
        initial=state_dict[n][0],
        after_state_change="callback",
    )
    for n in state_nr
}


def test_triggers(n):
    for _ in range(n_iter):
        machine = machines_dict[n]
        states = state_dict[n]
        while machine.models[0].state != states[-1]:
            machine.dispatch("go")
        machine.dispatch("to_" + states[0])


if __name__ == "__main__":
    import timeit
    import sys

    pyver = f"{sys.version_info.major}.{sys.version_info.minor}"
    print(f"{pyver} : {__version__}")
    with open("trigger_results.csv", "a") as f:
        for n in state_nr:
            samples = [
                timeit.timeit(
                    f"test_triggers({n})",
                    globals=globals(),
                    number=1,
                )
                * 1000
                / n_iter
                for _ in range(trials)
            ]
            mean = sum(samples) / trials
            stddev = (sum((x - mean) ** 2 for x in samples) / trials) ** 0.5
            print(
                f'"{pyver}","{__version__}","{n}","{mean:.2f}","{stddev:.2f}"',
                file=f,
            )
